package com.mm.security;

import com.mm.domen.User;
import com.mm.domen.enumtype.UserRoleEnum;
import com.mm.service.UserService;
import java.util.ArrayList;
import java.util.List;
import org.apache.tomcat.util.codec.binary.Base64;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.AccessDeniedException;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.GrantedAuthority;
import org.springframework.security.core.authority.SimpleGrantedAuthority;
import org.springframework.stereotype.Service;

/**
 *
 * @author Milos Milic
 */
@Service
public class TokenService {

    @Autowired
    private UserService userService;

    public String createTokenForUser(User user) throws Exception {
        return userService.authenticate(user);
    }

    public Authentication parseUserFromToken(String token) {
        try {
            String decoded = new String(Base64.decodeBase64(token));
            String username = decoded.substring(0, decoded.indexOf(":"));
            User user = userService.findByUsername(username);
            List<GrantedAuthority> lg = new ArrayList<>();
            for (UserRoleEnum r : user.getRoles()) {
                lg.add(new SimpleGrantedAuthority(r.name()));
            }
            TokenUser tu = new TokenUser(user, lg, token);
            tu.setAuthenticated(true);
            return tu;
        } catch (Exception ex) {
            throw new AccessDeniedException(ex.getMessage(), ex);
        }
    }

    public User getUserFromSpringAuthentication(Authentication authentication) {
        try {
            String currentPrincipalName = authentication.getName();
            return userService.findByUsername(currentPrincipalName);
        } catch (Exception ex) {
            throw new AccessDeniedException(ex.getMessage(), ex);
        }
    }
}
